DROP TABLE IF EXISTS Operacion;
DROP TABLE IF EXISTS Canje;
DROP TABLE IF EXISTS Split;
DROP TABLE IF EXISTS Cartera;
DROP TABLE IF EXISTS Usuario;
DROP TABLE IF EXISTS Valor;

CREATE TABLE Valor
(id int(10) not null auto_increment,
cod varchar(20) not null,
valor double not null default 0.0,
diferencia double,
dif double,
maximo double,
minimo double,
acciones double,
efectivo double,
capitalizacion double,
hora timestamp not null default CURRENT_TIMESTAMP,
ibex35 int(2) not null default 1,
PRIMARY KEY (id),
unique(cod)
)
ENGINE=InnoDB;


CREATE TABLE Usuario
(
id int(10) not null auto_increment,
nombre varchar(80) not null,
apellidos varchar(80) not null,
telefono varchar(30) not null default "",
direccion varchar(100) null,
email varchar(50) not null,
usuario varchar(50) not null,
password varchar(50) not null,
fechaAlta timestamp not null default CURRENT_TIMESTAMP,
PRIMARY KEY(id),
unique(usuario)
)ENGINE = InnoDB;

CREATE TABLE Cartera
(id int(10) not null auto_increment,
cod varchar(50) not null,
nombre varchar(50) not null,
comentarios text,
fechaAlta timestamp not null default CURRENT_TIMESTAMP,
principal tinyint(1) not null default 0,
fkUsuario int(10),
PRIMARY KEY(id),
unique(cod, fkUsuario),
CONSTRAINT fkUsuarioCa Foreign Key(fkUsuario) references Usuario(id) on delete restrict on update restrict
)ENGINE=InnoDB;


CREATE TABLE Operacion
(id int(10) not null auto_increment,
cod varchar(60) not null,
fkCartera int(10) not null,
fkValor int(10) not null,
tipo enum('Compra','Venta','Dividendo'),
fecha timestamp not null default CURRENT_TIMESTAMP,
comision double default 0.0,
volumen int(30),
cotizacion double,
PRIMARY KEY(id),
unique(cod),
CONSTRAINT fkCarteraOp Foreign Key(fkCartera) references Cartera(id) on delete restrict on update cascade,
CONSTRAINT fkValorOp Foreign Key(fkValor) references Valor(id) on delete restrict on update cascade
)ENGINE=InnoDB;

CREATE TABLE Canje
(id int(10) not null auto_increment,
cod varchar(60) not null,
cambio double not null,
fecha timestamp not null default CURRENT_TIMESTAMP,
fkValorF int(10) not null,
fkValorD int(10) not null,
fkCartera int(10) not null,
PRIMARY KEY(id),
unique(cod),
CONSTRAINT fkCarteraC Foreign Key(fkCartera) references Cartera(id) on delete restrict on update restrict,
CONSTRAINT fkValorCaF Foreign key(fkValorF) references Valor(id) on delete restrict on update restrict,
CONSTRAINT fkValorVaD Foreign key(fkValorD) references Valor(id) on delete restrict on update restrict
) ENGINE = InnoDB;

CREATE TABLE Split
(id int(10) not null auto_increment,
cod varchar(60) not null,
cambio double not null,
fecha timestamp not null default CURRENT_TIMESTAMP,
fkValor int(10) not null,
fkCartera int(10) not null,
PRIMARY KEY(id),
unique(cod),
CONSTRAINT fkCarteraS Foreign Key(fkCartera) references Cartera(id) on delete restrict on update restrict,
CONSTRAINT fkValorSp Foreign key(fkValor) references Valor(id) on delete restrict on update restrict
) ENGINE = InnoDB;